CreatePaymentSessionInput

Struct CreatePaymentSessionInput 

#[non_exhaustive]
pub struct CreatePaymentSessionInput { pub user_id: Option<String>, pub agent_name: Option<String>, pub payment_manager_arn: Option<String>, pub limits: Option<SessionLimits>, pub expiry_time_in_minutes: Option<i32>, pub client_token: Option<String>, }
Request structure for creating a payment session.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
user_id: Option<String>

The user ID associated with this payment session.

agent_name: Option<String>

The agent name associated with this request, used for observability.

payment_manager_arn: Option<String>

The ARN of the payment manager that owns this session.

limits: Option<SessionLimits>

The spending limits for this payment session.

expiry_time_in_minutes: Option<i32>

The session expiry time in minutes. Must be between 15 and 480 minutes.

client_token: Option<String>

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

Implementations

Source

impl CreatePaymentSessionInput

pub fn user_id(&self) -> Option<&str>

The user ID associated with this payment session.

pub fn agent_name(&self) -> Option<&str>

The agent name associated with this request, used for observability.

pub fn payment_manager_arn(&self) -> Option<&str>

The ARN of the payment manager that owns this session.

pub fn limits(&self) -> Option<&SessionLimits>

The spending limits for this payment session.

pub fn expiry_time_in_minutes(&self) -> Option<i32>

The session expiry time in minutes. Must be between 15 and 480 minutes.

pub fn client_token(&self) -> Option<&str>

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

Source

impl CreatePaymentSessionInput

pub fn builder() -> CreatePaymentSessionInputBuilder

Creates a new builder-style object to manufacture CreatePaymentSessionInput.