ProcessPaymentInput

Struct ProcessPaymentInput 

#[non_exhaustive]
pub struct ProcessPaymentInput { pub user_id: Option<String>, pub agent_name: Option<String>, pub payment_manager_arn: Option<String>, pub payment_session_id: Option<String>, pub payment_instrument_id: Option<String>, pub payment_type: Option<PaymentType>, pub payment_input: Option<PaymentInput>, pub client_token: Option<String>, }
Request structure for processing a payment.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
user_id: Option<String>

The user ID associated with this payment.

agent_name: Option<String>

The agent name associated with this request, used for observability.

payment_manager_arn: Option<String>

The ARN of the payment manager.

payment_session_id: Option<String>

The ID of the payment session.

payment_instrument_id: Option<String>

The ID of the payment instrument to use.

payment_type: Option<PaymentType>

The type of payment to process.

payment_input: Option<PaymentInput>

The payment input details specific to the payment type.

client_token: Option<String>

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

Implementations

Source

impl ProcessPaymentInput

pub fn user_id(&self) -> Option<&str>

The user ID associated with this payment.

pub fn agent_name(&self) -> Option<&str>

The agent name associated with this request, used for observability.

pub fn payment_manager_arn(&self) -> Option<&str>

The ARN of the payment manager.

pub fn payment_session_id(&self) -> Option<&str>

The ID of the payment session.

pub fn payment_instrument_id(&self) -> Option<&str>

The ID of the payment instrument to use.

pub fn payment_type(&self) -> Option<&PaymentType>

The type of payment to process.

pub fn payment_input(&self) -> Option<&PaymentInput>

The payment input details specific to the payment type.

pub fn client_token(&self) -> Option<&str>

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

Source

impl ProcessPaymentInput

pub fn builder() -> ProcessPaymentInputBuilder

Creates a new builder-style object to manufacture ProcessPaymentInput.