ProcessPaymentOutput

Struct ProcessPaymentOutput 

#[non_exhaustive]
pub struct ProcessPaymentOutput { pub process_payment_id: String, pub payment_manager_arn: String, pub payment_session_id: String, pub payment_instrument_id: String, pub payment_type: PaymentType, pub status: PaymentStatus, pub payment_output: Option<PaymentOutput>, pub created_at: DateTime, pub updated_at: DateTime, /* private fields */ }
Response structure for processing a payment.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
process_payment_id: String

The unique identifier of the processed payment.

payment_manager_arn: String

The ARN of the payment manager.

payment_session_id: String

The ID of the payment session used.

payment_instrument_id: String

The ID of the payment instrument used.

payment_type: PaymentType

The type of payment processed.

status: PaymentStatus

The status of the payment.

payment_output: Option<PaymentOutput>

The payment output details specific to the payment type.

created_at: DateTime

The timestamp when the payment was created.

updated_at: DateTime

The timestamp when the payment was last updated.

Implementations

Source

impl ProcessPaymentOutput

pub fn process_payment_id(&self) -> &str

The unique identifier of the processed payment.

pub fn payment_manager_arn(&self) -> &str

The ARN of the payment manager.

pub fn payment_session_id(&self) -> &str

The ID of the payment session used.

pub fn payment_instrument_id(&self) -> &str

The ID of the payment instrument used.

pub fn payment_type(&self) -> &PaymentType

The type of payment processed.

pub fn status(&self) -> &PaymentStatus

The status of the payment.

pub fn payment_output(&self) -> Option<&PaymentOutput>

The payment output details specific to the payment type.

pub fn created_at(&self) -> &DateTime

The timestamp when the payment was created.

pub fn updated_at(&self) -> &DateTime

The timestamp when the payment was last updated.

Source

impl ProcessPaymentOutput

pub fn builder() -> ProcessPaymentOutputBuilder

Creates a new builder-style object to manufacture ProcessPaymentOutput.