Client

Struct Client 

pub struct Client { /* private fields */ }
Client for Amazon Bedrock AgentCore

Client for invoking operations on Amazon Bedrock AgentCore. Each operation on Amazon Bedrock AgentCore is a method on this this struct. .send() MUST be invoked on the generated operations to dispatch the request to the service.

Constructing a Client

A Config is required to construct a client. For most use cases, the aws-config crate should be used to automatically resolve this config using aws_config::load_from_env(), since this will resolve an SdkConfig which can be shared across multiple different AWS SDK clients. This config resolution process can be customized by calling aws_config::from_env() instead, which returns a ConfigLoader that uses the builder pattern to customize the default config.

In the simplest case, creating a client looks as follows:

let config = aws_config::load_from_env().await;
let client = aws_sdk_bedrockagentcore::Client::new(&config);

Occasionally, SDKs may have additional service-specific values that can be set on the Config that is absent from SdkConfig, or slightly different settings for a specific client may be desired. The Builder struct implements From<&SdkConfig>, so setting these specific settings can be done as follows:

let sdk_config = ::aws_config::load_from_env().await;
let config = aws_sdk_bedrockagentcore::config::Builder::from(&sdk_config)
    .some_service_specific_setting("value")
    .build();

See the aws-config docs and Config for more information on customizing configuration.

Note: Client construction is expensive due to connection thread pool initialization, and should be done once at application start-up.

Using the Client

A client has a function for every operation that can be performed by the service. For example, the BatchCreateMemoryRecords operation has a Client::batch_create_memory_records, function which returns a builder for that operation. The fluent builder ultimately has a send() function that returns an async future that returns a result, as illustrated below:

let result = client.batch_create_memory_records()
    .memory_id("example")
    .send()
    .await;

The underlying HTTP requests that get made by this can be modified with the customize_operation function on the fluent builder. See the customize module for more information.

Implementations

Source

impl Client

pub fn batch_create_memory_records( &self, ) -> BatchCreateMemoryRecordsFluentBuilder

Constructs a fluent builder for the BatchCreateMemoryRecords operation.

Source

impl Client

pub fn batch_delete_memory_records( &self, ) -> BatchDeleteMemoryRecordsFluentBuilder

Constructs a fluent builder for the BatchDeleteMemoryRecords operation.

Source

impl Client

pub fn batch_update_memory_records( &self, ) -> BatchUpdateMemoryRecordsFluentBuilder

Constructs a fluent builder for the BatchUpdateMemoryRecords operation.

Source

impl Client

pub fn complete_resource_token_auth( &self, ) -> CompleteResourceTokenAuthFluentBuilder

Constructs a fluent builder for the CompleteResourceTokenAuth operation.

Source

impl Client

pub fn create_ab_test(&self) -> CreateABTestFluentBuilder

Constructs a fluent builder for the CreateABTest operation.

Source

impl Client

pub fn create_event(&self) -> CreateEventFluentBuilder

Constructs a fluent builder for the CreateEvent operation.

Source

impl Client

pub fn create_payment_instrument(&self) -> CreatePaymentInstrumentFluentBuilder

Constructs a fluent builder for the CreatePaymentInstrument operation.

Source

impl Client

pub fn create_payment_session(&self) -> CreatePaymentSessionFluentBuilder

Constructs a fluent builder for the CreatePaymentSession operation.

Source

impl Client

pub fn delete_ab_test(&self) -> DeleteABTestFluentBuilder

Constructs a fluent builder for the DeleteABTest operation.

Source

impl Client

pub fn delete_batch_evaluation(&self) -> DeleteBatchEvaluationFluentBuilder

Constructs a fluent builder for the DeleteBatchEvaluation operation.

Source

impl Client

pub fn delete_event(&self) -> DeleteEventFluentBuilder

Constructs a fluent builder for the DeleteEvent operation.

Source

impl Client

pub fn delete_memory_record(&self) -> DeleteMemoryRecordFluentBuilder

Constructs a fluent builder for the DeleteMemoryRecord operation.

Source

impl Client

pub fn delete_payment_instrument(&self) -> DeletePaymentInstrumentFluentBuilder

Constructs a fluent builder for the DeletePaymentInstrument operation.

Source

impl Client

pub fn delete_payment_session(&self) -> DeletePaymentSessionFluentBuilder

Constructs a fluent builder for the DeletePaymentSession operation.

Source

impl Client

pub fn delete_recommendation(&self) -> DeleteRecommendationFluentBuilder

Constructs a fluent builder for the DeleteRecommendation operation.

Source

impl Client

pub fn evaluate(&self) -> EvaluateFluentBuilder

Constructs a fluent builder for the Evaluate operation.

Source

impl Client

pub fn get_ab_test(&self) -> GetABTestFluentBuilder

Constructs a fluent builder for the GetABTest operation.

Source

impl Client

pub fn get_agent_card(&self) -> GetAgentCardFluentBuilder

Constructs a fluent builder for the GetAgentCard operation.

Source

impl Client

pub fn get_batch_evaluation(&self) -> GetBatchEvaluationFluentBuilder

Constructs a fluent builder for the GetBatchEvaluation operation.

Source

impl Client

pub fn get_browser_session(&self) -> GetBrowserSessionFluentBuilder

Constructs a fluent builder for the GetBrowserSession operation.

Source

impl Client

pub fn get_code_interpreter_session( &self, ) -> GetCodeInterpreterSessionFluentBuilder

Constructs a fluent builder for the GetCodeInterpreterSession operation.

Source

impl Client

pub fn get_event(&self) -> GetEventFluentBuilder

Constructs a fluent builder for the GetEvent operation.

Source

impl Client

pub fn get_memory_record(&self) -> GetMemoryRecordFluentBuilder

Constructs a fluent builder for the GetMemoryRecord operation.

Source

impl Client

pub fn get_payment_instrument(&self) -> GetPaymentInstrumentFluentBuilder

Constructs a fluent builder for the GetPaymentInstrument operation.

Source

impl Client

pub fn get_payment_instrument_balance( &self, ) -> GetPaymentInstrumentBalanceFluentBuilder

Constructs a fluent builder for the GetPaymentInstrumentBalance operation.

Source

impl Client

pub fn get_payment_session(&self) -> GetPaymentSessionFluentBuilder

Constructs a fluent builder for the GetPaymentSession operation.

Source

impl Client

pub fn get_recommendation(&self) -> GetRecommendationFluentBuilder

Constructs a fluent builder for the GetRecommendation operation.

Source

impl Client

pub fn get_resource_api_key(&self) -> GetResourceApiKeyFluentBuilder

Constructs a fluent builder for the GetResourceApiKey operation.

Source

impl Client

pub fn get_resource_oauth2_token(&self) -> GetResourceOauth2TokenFluentBuilder

Constructs a fluent builder for the GetResourceOauth2Token operation.

Source

impl Client

pub fn get_resource_payment_token(&self) -> GetResourcePaymentTokenFluentBuilder

Constructs a fluent builder for the GetResourcePaymentToken operation.

Source

impl Client

pub fn get_workload_access_token(&self) -> GetWorkloadAccessTokenFluentBuilder

Constructs a fluent builder for the GetWorkloadAccessToken operation.

Source

impl Client

pub fn get_workload_access_token_for_jwt( &self, ) -> GetWorkloadAccessTokenForJWTFluentBuilder

Constructs a fluent builder for the GetWorkloadAccessTokenForJWT operation.

Source

impl Client

pub fn get_workload_access_token_for_user_id( &self, ) -> GetWorkloadAccessTokenForUserIdFluentBuilder

Constructs a fluent builder for the GetWorkloadAccessTokenForUserId operation.

Source

impl Client

pub fn invoke_agent_runtime(&self) -> InvokeAgentRuntimeFluentBuilder

Constructs a fluent builder for the InvokeAgentRuntime operation.

Source

impl Client

pub fn invoke_agent_runtime_command( &self, ) -> InvokeAgentRuntimeCommandFluentBuilder

Constructs a fluent builder for the InvokeAgentRuntimeCommand operation.

Source

impl Client

pub fn invoke_browser(&self) -> InvokeBrowserFluentBuilder

Constructs a fluent builder for the InvokeBrowser operation.

Source

impl Client

pub fn invoke_code_interpreter(&self) -> InvokeCodeInterpreterFluentBuilder

Constructs a fluent builder for the InvokeCodeInterpreter operation.

Source

impl Client

pub fn invoke_harness(&self) -> InvokeHarnessFluentBuilder

Constructs a fluent builder for the InvokeHarness operation.

Source

impl Client

pub fn list_ab_tests(&self) -> ListABTestsFluentBuilder

Constructs a fluent builder for the ListABTests operation. This operation supports pagination; See into_paginator().

  • The fluent builder is configurable:
    • max_results(i32) / set_max_results(Option<i32>):
      required: false

      The maximum number of results to return in the response. If the total number of results is greater than this value, use the token returned in the response in the nextToken field when making another request to return the next batch of results.


    • next_token(impl Into<String>) / set_next_token(Option<String>):
      required: false

      If the total number of results is greater than the maxResults value provided in the request, enter the token returned in the nextToken field in the response in this field to return the next batch of results.


  • On success, responds with ListAbTestsOutput with field(s):
    • ab_tests(Vec::<AbTestSummary>):

      The list of A/B test summaries.

    • next_token(Option<String>):

      If the total number of results is greater than the maxResults value provided in the request, use this token when making another request in the nextToken field to return the next batch of results.

  • On failure, responds with SdkError<ListABTestsError>
Source

impl Client

pub fn list_actors(&self) -> ListActorsFluentBuilder

Constructs a fluent builder for the ListActors operation. This operation supports pagination; See into_paginator().

Source

impl Client

pub fn list_batch_evaluations(&self) -> ListBatchEvaluationsFluentBuilder

Constructs a fluent builder for the ListBatchEvaluations operation. This operation supports pagination; See into_paginator().

Source

impl Client

pub fn list_browser_sessions(&self) -> ListBrowserSessionsFluentBuilder

Constructs a fluent builder for the ListBrowserSessions operation.

Source

impl Client

pub fn list_code_interpreter_sessions( &self, ) -> ListCodeInterpreterSessionsFluentBuilder

Constructs a fluent builder for the ListCodeInterpreterSessions operation.

Source

impl Client

pub fn list_events(&self) -> ListEventsFluentBuilder

Constructs a fluent builder for the ListEvents operation. This operation supports pagination; See into_paginator().

Source

impl Client

pub fn list_memory_extraction_jobs( &self, ) -> ListMemoryExtractionJobsFluentBuilder

Constructs a fluent builder for the ListMemoryExtractionJobs operation. This operation supports pagination; See into_paginator().

Source

impl Client

pub fn list_memory_records(&self) -> ListMemoryRecordsFluentBuilder

Constructs a fluent builder for the ListMemoryRecords operation. This operation supports pagination; See into_paginator().

Source

impl Client

pub fn list_payment_instruments(&self) -> ListPaymentInstrumentsFluentBuilder

Constructs a fluent builder for the ListPaymentInstruments operation. This operation supports pagination; See into_paginator().

Source

impl Client

pub fn list_payment_sessions(&self) -> ListPaymentSessionsFluentBuilder

Constructs a fluent builder for the ListPaymentSessions operation. This operation supports pagination; See into_paginator().

Source

impl Client

pub fn list_recommendations(&self) -> ListRecommendationsFluentBuilder

Constructs a fluent builder for the ListRecommendations operation. This operation supports pagination; See into_paginator().

Source

impl Client

pub fn list_sessions(&self) -> ListSessionsFluentBuilder

Constructs a fluent builder for the ListSessions operation. This operation supports pagination; See into_paginator().

Source

impl Client

pub fn process_payment(&self) -> ProcessPaymentFluentBuilder

Constructs a fluent builder for the ProcessPayment operation.

Source

impl Client

pub fn retrieve_memory_records(&self) -> RetrieveMemoryRecordsFluentBuilder

Constructs a fluent builder for the RetrieveMemoryRecords operation. This operation supports pagination; See into_paginator().

Source

impl Client

pub fn save_browser_session_profile( &self, ) -> SaveBrowserSessionProfileFluentBuilder

Constructs a fluent builder for the SaveBrowserSessionProfile operation.

Source

impl Client

pub fn search_registry_records(&self) -> SearchRegistryRecordsFluentBuilder

Constructs a fluent builder for the SearchRegistryRecords operation.

Source

impl Client

pub fn start_batch_evaluation(&self) -> StartBatchEvaluationFluentBuilder

Constructs a fluent builder for the StartBatchEvaluation operation.

Source

impl Client

pub fn start_browser_session(&self) -> StartBrowserSessionFluentBuilder

Constructs a fluent builder for the StartBrowserSession operation.

Source

impl Client

pub fn start_code_interpreter_session( &self, ) -> StartCodeInterpreterSessionFluentBuilder

Constructs a fluent builder for the StartCodeInterpreterSession operation.

Source

impl Client

pub fn start_memory_extraction_job( &self, ) -> StartMemoryExtractionJobFluentBuilder

Constructs a fluent builder for the StartMemoryExtractionJob operation.

Source

impl Client

pub fn start_recommendation(&self) -> StartRecommendationFluentBuilder

Constructs a fluent builder for the StartRecommendation operation.

Source

impl Client

pub fn stop_batch_evaluation(&self) -> StopBatchEvaluationFluentBuilder

Constructs a fluent builder for the StopBatchEvaluation operation.

Source

impl Client

pub fn stop_browser_session(&self) -> StopBrowserSessionFluentBuilder

Constructs a fluent builder for the StopBrowserSession operation.

Source

impl Client

pub fn stop_code_interpreter_session( &self, ) -> StopCodeInterpreterSessionFluentBuilder

Constructs a fluent builder for the StopCodeInterpreterSession operation.

Source

impl Client

pub fn stop_runtime_session(&self) -> StopRuntimeSessionFluentBuilder

Constructs a fluent builder for the StopRuntimeSession operation.

Source

impl Client

pub fn update_ab_test(&self) -> UpdateABTestFluentBuilder

Constructs a fluent builder for the UpdateABTest operation.

Source

impl Client

pub fn update_browser_stream(&self) -> UpdateBrowserStreamFluentBuilder

Constructs a fluent builder for the UpdateBrowserStream operation.

Source

impl Client

pub fn from_conf(conf: Config) -> Self

Creates a new client from the service Config.

Panics

This method will panic in the following cases:

  • Retries or timeouts are enabled without a sleep_impl configured.
  • Identity caching is enabled without a sleep_impl and time_source configured.
  • No behavior_version is provided.

The panic message for each of these will have instructions on how to resolve them.

pub fn config(&self) -> &Config

Returns the client’s configuration.

Source

impl Client

pub fn new(sdk_config: &SdkConfig) -> Self

Creates a new client from an SDK Config.

Panics
  • This method will panic if the sdk_config is missing an async sleep implementation. If you experience this panic, set the sleep_impl on the Config passed into this function to fix it.
  • This method will panic if the sdk_config is missing an HTTP connector. If you experience this panic, set the http_connector on the Config passed into this function to fix it.
  • This method will panic if no BehaviorVersion is provided. If you experience this panic, set behavior_version on the Config or enable the behavior-version-latest Cargo feature.