#[non_exhaustive]pub struct CreatePaymentSessionInput {
pub user_id: Option<String>,
pub agent_name: Option<String>,
pub payment_manager_arn: Option<String>,
pub limits: Option<SessionLimits>,
pub expiry_time_in_minutes: Option<i32>,
pub client_token: Option<String>,
}Expand description
Request structure for creating a payment session.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.user_id: Option<String>The user ID associated with this payment session.
agent_name: Option<String>The agent name associated with this request, used for observability.
payment_manager_arn: Option<String>The ARN of the payment manager that owns this session.
limits: Option<SessionLimits>The spending limits for this payment session.
expiry_time_in_minutes: Option<i32>The session expiry time in minutes. Must be between 15 and 480 minutes.
client_token: Option<String>A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Implementations
Sourceimpl CreatePaymentSessionInput
impl CreatePaymentSessionInput
Sourcepub fn agent_name(&self) -> Option<&str>
pub fn agent_name(&self) -> Option<&str>
The agent name associated with this request, used for observability.
Sourcepub fn payment_manager_arn(&self) -> Option<&str>
pub fn payment_manager_arn(&self) -> Option<&str>
The ARN of the payment manager that owns this session.
Sourcepub fn limits(&self) -> Option<&SessionLimits>
pub fn limits(&self) -> Option<&SessionLimits>
The spending limits for this payment session.
Sourcepub fn expiry_time_in_minutes(&self) -> Option<i32>
pub fn expiry_time_in_minutes(&self) -> Option<i32>
The session expiry time in minutes. Must be between 15 and 480 minutes.
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourceimpl CreatePaymentSessionInput
impl CreatePaymentSessionInput
Sourcepub fn builder() -> CreatePaymentSessionInputBuilder
pub fn builder() -> CreatePaymentSessionInputBuilder
Creates a new builder-style object to manufacture CreatePaymentSessionInput.