#[non_exhaustive]pub struct ProcessPaymentInput {
pub user_id: Option<String>,
pub agent_name: Option<String>,
pub payment_manager_arn: Option<String>,
pub payment_session_id: Option<String>,
pub payment_instrument_id: Option<String>,
pub payment_type: Option<PaymentType>,
pub payment_input: Option<PaymentInput>,
pub client_token: Option<String>,
}Expand description
Request structure for processing a payment.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.user_id: Option<String>The user ID associated with this payment.
agent_name: Option<String>The agent name associated with this request, used for observability.
payment_manager_arn: Option<String>The ARN of the payment manager.
payment_session_id: Option<String>The ID of the payment session.
payment_instrument_id: Option<String>The ID of the payment instrument to use.
payment_type: Option<PaymentType>The type of payment to process.
payment_input: Option<PaymentInput>The payment input details specific to the payment type.
client_token: Option<String>A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Implementations
Sourceimpl ProcessPaymentInput
impl ProcessPaymentInput
Sourcepub fn agent_name(&self) -> Option<&str>
pub fn agent_name(&self) -> Option<&str>
The agent name associated with this request, used for observability.
Sourcepub fn payment_manager_arn(&self) -> Option<&str>
pub fn payment_manager_arn(&self) -> Option<&str>
The ARN of the payment manager.
Sourcepub fn payment_session_id(&self) -> Option<&str>
pub fn payment_session_id(&self) -> Option<&str>
The ID of the payment session.
Sourcepub fn payment_instrument_id(&self) -> Option<&str>
pub fn payment_instrument_id(&self) -> Option<&str>
The ID of the payment instrument to use.
Sourcepub fn payment_type(&self) -> Option<&PaymentType>
pub fn payment_type(&self) -> Option<&PaymentType>
The type of payment to process.
Sourcepub fn payment_input(&self) -> Option<&PaymentInput>
pub fn payment_input(&self) -> Option<&PaymentInput>
The payment input details specific to the payment type.
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourceimpl ProcessPaymentInput
impl ProcessPaymentInput
Sourcepub fn builder() -> ProcessPaymentInputBuilder
pub fn builder() -> ProcessPaymentInputBuilder
Creates a new builder-style object to manufacture ProcessPaymentInput.