#[non_exhaustive]pub struct ProcessPaymentOutput {
pub process_payment_id: String,
pub payment_manager_arn: String,
pub payment_session_id: String,
pub payment_instrument_id: String,
pub payment_type: PaymentType,
pub status: PaymentStatus,
pub payment_output: Option<PaymentOutput>,
pub created_at: DateTime,
pub updated_at: DateTime,
/* private fields */
}Expand description
Response structure for processing a payment.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.process_payment_id: StringThe unique identifier of the processed payment.
payment_manager_arn: StringThe ARN of the payment manager.
payment_session_id: StringThe ID of the payment session used.
payment_instrument_id: StringThe ID of the payment instrument used.
payment_type: PaymentTypeThe type of payment processed.
status: PaymentStatusThe status of the payment.
payment_output: Option<PaymentOutput>The payment output details specific to the payment type.
created_at: DateTimeThe timestamp when the payment was created.
updated_at: DateTimeThe timestamp when the payment was last updated.
Implementations
Sourceimpl ProcessPaymentOutput
impl ProcessPaymentOutput
Sourcepub fn process_payment_id(&self) -> &str
pub fn process_payment_id(&self) -> &str
The unique identifier of the processed payment.
Sourcepub fn payment_manager_arn(&self) -> &str
pub fn payment_manager_arn(&self) -> &str
The ARN of the payment manager.
Sourcepub fn payment_session_id(&self) -> &str
pub fn payment_session_id(&self) -> &str
The ID of the payment session used.
Sourcepub fn payment_instrument_id(&self) -> &str
pub fn payment_instrument_id(&self) -> &str
The ID of the payment instrument used.
Sourcepub fn payment_type(&self) -> &PaymentType
pub fn payment_type(&self) -> &PaymentType
The type of payment processed.
Sourcepub fn status(&self) -> &PaymentStatus
pub fn status(&self) -> &PaymentStatus
The status of the payment.
Sourcepub fn payment_output(&self) -> Option<&PaymentOutput>
pub fn payment_output(&self) -> Option<&PaymentOutput>
The payment output details specific to the payment type.
Sourcepub fn created_at(&self) -> &DateTime
pub fn created_at(&self) -> &DateTime
The timestamp when the payment was created.
Sourcepub fn updated_at(&self) -> &DateTime
pub fn updated_at(&self) -> &DateTime
The timestamp when the payment was last updated.
Sourceimpl ProcessPaymentOutput
impl ProcessPaymentOutput
Sourcepub fn builder() -> ProcessPaymentOutputBuilder
pub fn builder() -> ProcessPaymentOutputBuilder
Creates a new builder-style object to manufacture ProcessPaymentOutput.